![run_tests workflow](https://github.com/bernhardschaefer/yamlu/actions/workflows/run_tests.yaml/badge.svg)

## yamlu - yet another machine learning utility library

### Installation

```shell
pip install -U git+https://github.com/bernhardschaefer/yamlu.git
```